==> voreen-src-4.1.1-win.zip: voreen-src-4.1.1-win/modules/base/processors/geometry/geometrytransformationvolume.h <==
/***********************************************************************************
 *                                                                                 *
 * Voreen - The Volume Rendering Engine                                            *
 *                                                                                 *
 * Copyright (C) 2005-2012 University of Muenster, Germany.                        *
 * Visualization and Computer Graphics Group <http://viscg.uni-muenster.de>        *
 * For a list of authors please refer to the file "CREDITS.txt".                   *
 *                                                                                 *
 * This file is part of the Voreen software package. Voreen is free software:      *
 * you can redistribute it and/or modify it under the terms of the GNU General     *
 * Public License version 2 as published by the Free Software Foundation.          *
 *                                                                                 *
 * Voreen is distributed in the hope that it will be useful, but WITHOUT ANY       *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR   *
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.      *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License in the file   *
 * "LICENSE.txt" along with this file. If not, see <http://www.gnu.org/licenses/>. *
 *                                                                                 *
 * For non-commercial academic use see the license exception specified in the file *
 * "LICENSE-academic.txt". To get information about commercial licensing please    *
 * contact the authors.                                                            *
 *                                                                                 *
 ***********************************************************************************/

#ifndef VRN_GEOMETRYTRANSFORMATIONVOLUME_H
#define VRN_GEOMETRYTRANSFORMATIONVOLUME_H

#include "voreen/core/processors/processor.h"
#include "voreen/core/ports/geometryport.h"
#include "voreen/core/ports/volumeport.h"

#include "voreen/core/properties/optionproperty.h"
#include "voreen/core/properties/boolproperty.h"

namespace voreen {

class GeometryTransformationVolume : public Processor {
public:
    GeometryTransformationVolume();
    virtual Processor* create() const;

    virtual std::string getClassName() const { return "GeometryTransformationVolume"; }
    virtual std::string getCategory() const  { return "Geometry";                     }
    virtual CodeState getCodeState() const   { return CODE_STATE_STABLE;              }

protected:
    virtual void setDescriptions() {
        setDescription("Transforms geometry coordinates between volume-dependent coordinate systems.");
    }

    virtual void process();

private:
    void forceUpdate(); /// called on change of the coordinates selection properties

    GeometryPort geometryInport_;
    VolumePort volumeInport_;
    GeometryPort geometryOutport_;

    BoolProperty enableProcessing_;
    StringOptionProperty sourceCoordinateSystem_;
    StringOptionProperty targetCoordinateSystem_;

    bool forceUpdate_;  // set to true if coordinate system selection has changed

    static const std::string loggerCat_;
};

}   //namespace

#endif // VRN_GEOMETRYTRANSFORMATIONVOLUME_H

==> voreen-src-4.4-win.zip: voreen-src-4.4-win/modules/base/processors/geometry/geometrytransformationvolume.h <==
/***********************************************************************************
 *                                                                                 *
 * Voreen - The Volume Rendering Engine                                            *
 *                                                                                 *
 * Copyright (C) 2005-2013 University of Muenster, Germany.                        *
 * Visualization and Computer Graphics Group <http://viscg.uni-muenster.de>        *
 * For a list of authors please refer to the file "CREDITS.txt".                   *
 *                                                                                 *
 * This file is part of the Voreen software package. Voreen is free software:      *
 * you can redistribute it and/or modify it under the terms of the GNU General     *
 * Public License version 2 as published by the Free Software Foundation.          *
 *                                                                                 *
 * Voreen is distributed in the hope that it will be useful, but WITHOUT ANY       *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR   *
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.      *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License in the file   *
 * "LICENSE.txt" along with this file. If not, see <http://www.gnu.org/licenses/>. *
 *                                                                                 *
 * For non-commercial academic use see the license exception specified in the file *
 * "LICENSE-academic.txt". To get information about commercial licensing please    *
 * contact the authors.                                                            *
 *                                                                                 *
 ***********************************************************************************/

#ifndef VRN_GEOMETRYTRANSFORMATIONVOLUME_H
#define VRN_GEOMETRYTRANSFORMATIONVOLUME_H

#include "voreen/core/processors/processor.h"
#include "voreen/core/ports/geometryport.h"
#include "voreen/core/ports/volumeport.h"

#include "voreen/core/properties/optionproperty.h"
#include "voreen/core/properties/boolproperty.h"

namespace voreen {

class VRN_CORE_API GeometryTransformationVolume : public Processor {
public:
    GeometryTransformationVolume();
    virtual Processor* create() const;

    virtual std::string getClassName() const { return "GeometryTransformationVolume"; }
    virtual std::string getCategory() const  { return "Geometry";                     }
    virtual CodeState getCodeState() const   { return CODE_STATE_STABLE;              }

protected:
    virtual void setDescriptions() {
        setDescription("Transforms geometry coordinates between volume-dependent coordinate systems.");
    }

    virtual void process();

private:
    void forceUpdate(); /// called on change of the coordinates selection properties

    GeometryPort geometryInport_;
    VolumePort volumeInport_;
    GeometryPort geometryOutport_;

    BoolProperty enableProcessing_;
    StringOptionProperty sourceCoordinateSystem_;
    StringOptionProperty targetCoordinateSystem_;

    bool forceUpdate_;  // set to true if coordinate system selection has changed

    static const std::string loggerCat_;
};

}   //namespace

#endif // VRN_GEOMETRYTRANSFORMATIONVOLUME_H
